# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apexnova/entity/entity_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'apexnova/entity/entity_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from apexnova.entity import entity_pb2 as apexnova_dot_entity_dot_entity__pb2
from apexnova.stub import authorization_context_pb2 as apexnova_dot_stub_dot_authorization__context__pb2
from apexnova.stub import response_pb2 as apexnova_dot_stub_dot_response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$apexnova/entity/entity_service.proto\x12\x06\x65ntity\x1a\x1c\x61pexnova/entity/entity.proto\x1a)apexnova/stub/authorization_context.proto\x1a\x1c\x61pexnova/stub/response.proto\"\x9a\x01\n\x1d\x43reateEntityUploadLinkRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\x12\n\naccount_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0c\n\x04tags\x18\x06 \x03(\t\"\x81\x01\n\x1e\x43reateEntityUploadLinkResponse\x12\x1e\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x0e.entity.Entity\x12\x11\n\tsas_token\x18\x02 \x01(\t\x12,\n\x11standard_response\x18\x03 \x01(\x0b\x32\x11.StandardResponse\"U\n\x11ReadEntityRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\n\n\x02id\x18\x02 \x01(\t\"u\n\x12ReadEntityResponse\x12\x1e\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x0e.entity.Entity\x12\x11\n\tsas_token\x18\x02 \x01(\t\x12,\n\x11standard_response\x18\x03 \x01(\x0b\x32\x11.StandardResponse\"\x88\x01\n\x13UpdateEntityRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x0c\n\x04tags\x18\x07 \x03(\t\"d\n\x14UpdateEntityResponse\x12\x1e\n\x06\x65ntity\x18\x02 \x01(\x0b\x32\x0e.entity.Entity\x12,\n\x11standard_response\x18\x03 \x01(\x0b\x32\x11.StandardResponse\"W\n\x13\x44\x65leteEntityRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\n\n\x02id\x18\x02 \x01(\t\"P\n\x14\x44\x65leteEntityResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"\x89\x01\n\x15\x46ilterEntitiesRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\x12\n\naccount_id\x18\x02 \x01(\t\x12\x17\n\x0fprevious_cursor\x18\x03 \x01(\t\x12\r\n\x05limit\x18\x07 \x01(\x05\"\xc4\x01\n\x16\x46ilterEntitiesResponse\x12 \n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x0e.entity.Entity\x12\x14\n\x0cstart_cursor\x18\x02 \x01(\t\x12\x12\n\nend_cursor\x18\x06 \x01(\t\x12\x15\n\rhas_next_page\x18\x04 \x01(\x08\x12\x19\n\x11has_previous_page\x18\x05 \x01(\x08\x12,\n\x11standard_response\x18\x03 \x01(\x0b\x32\x11.StandardResponse\"Z\n\x15\x44\x65leteEntitiesRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\x0b\n\x03ids\x18\x02 \x03(\t\"|\n\x15UpdateEntitiesRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12-\n\x08\x65ntities\x18\x02 \x03(\x0b\x32\x1b.entity.UpdateEntityRequest2\xc6\x04\n\rEntityService\x12g\n\x16\x43reateEntityUploadLink\x12%.entity.CreateEntityUploadLinkRequest\x1a&.entity.CreateEntityUploadLinkResponse\x12\x43\n\nReadEntity\x12\x19.entity.ReadEntityRequest\x1a\x1a.entity.ReadEntityResponse\x12I\n\x0cUpdateEntity\x12\x1b.entity.UpdateEntityRequest\x1a\x1c.entity.UpdateEntityResponse\x12I\n\x0c\x44\x65leteEntity\x12\x1b.entity.DeleteEntityRequest\x1a\x1c.entity.DeleteEntityResponse\x12O\n\x0e\x46ilterEntities\x12\x1d.entity.FilterEntitiesRequest\x1a\x1e.entity.FilterEntitiesResponse\x12O\n\x0eUpdateEntities\x12\x1d.entity.UpdateEntitiesRequest\x1a\x1c.entity.UpdateEntityResponse0\x01\x12O\n\x0e\x44\x65leteEntities\x12\x1d.entity.DeleteEntitiesRequest\x1a\x1c.entity.DeleteEntityResponse0\x01\x42+\n\x13\x63om.apexnova.entityB\x12\x45ntityServiceProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apexnova.entity.entity_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.apexnova.entityB\022EntityServiceProtoP\001'
  _globals['_CREATEENTITYUPLOADLINKREQUEST']._serialized_start=152
  _globals['_CREATEENTITYUPLOADLINKREQUEST']._serialized_end=306
  _globals['_CREATEENTITYUPLOADLINKRESPONSE']._serialized_start=309
  _globals['_CREATEENTITYUPLOADLINKRESPONSE']._serialized_end=438
  _globals['_READENTITYREQUEST']._serialized_start=440
  _globals['_READENTITYREQUEST']._serialized_end=525
  _globals['_READENTITYRESPONSE']._serialized_start=527
  _globals['_READENTITYRESPONSE']._serialized_end=644
  _globals['_UPDATEENTITYREQUEST']._serialized_start=647
  _globals['_UPDATEENTITYREQUEST']._serialized_end=783
  _globals['_UPDATEENTITYRESPONSE']._serialized_start=785
  _globals['_UPDATEENTITYRESPONSE']._serialized_end=885
  _globals['_DELETEENTITYREQUEST']._serialized_start=887
  _globals['_DELETEENTITYREQUEST']._serialized_end=974
  _globals['_DELETEENTITYRESPONSE']._serialized_start=976
  _globals['_DELETEENTITYRESPONSE']._serialized_end=1056
  _globals['_FILTERENTITIESREQUEST']._serialized_start=1059
  _globals['_FILTERENTITIESREQUEST']._serialized_end=1196
  _globals['_FILTERENTITIESRESPONSE']._serialized_start=1199
  _globals['_FILTERENTITIESRESPONSE']._serialized_end=1395
  _globals['_DELETEENTITIESREQUEST']._serialized_start=1397
  _globals['_DELETEENTITIESREQUEST']._serialized_end=1487
  _globals['_UPDATEENTITIESREQUEST']._serialized_start=1489
  _globals['_UPDATEENTITIESREQUEST']._serialized_end=1613
  _globals['_ENTITYSERVICE']._serialized_start=1616
  _globals['_ENTITYSERVICE']._serialized_end=2198
# @@protoc_insertion_point(module_scope)
