# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apexnova/stub/response.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'apexnova/stub/response.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61pexnova/stub/response.proto\"O\n\x10StandardResponse\x12$\n\x0bstatus_code\x18\x01 \x01(\x0e\x32\x0f.ResponseStatus\x12\x15\n\rerror_message\x18\x02 \x01(\t*\x8b\x03\n\x0eResponseStatus\x12\x1f\n\x1bRESPONSE_STATUS_UNSPECIFIED\x10\x00\x12\x1b\n\x17RESPONSE_STATUS_SUCCESS\x10\x01\x12\x1d\n\x19RESPONSE_STATUS_NOT_FOUND\x10\x02\x12$\n RESPONSE_STATUS_INVALID_ARGUMENT\x10\x03\x12%\n!RESPONSE_STATUS_PERMISSION_DENIED\x10\x04\x12\"\n\x1eRESPONSE_STATUS_INTERNAL_ERROR\x10\x05\x12#\n\x1fRESPONSE_STATUS_UNAUTHENTICATED\x10\x06\x12\x1f\n\x1bRESPONSE_STATUS_BAD_REQUEST\x10\x07\x12\'\n#RESPONSE_STATUS_FAILED_PRECONDITION\x10\x08\x12\x1f\n\x1bRESPONSE_STATUS_UNAVAILABLE\x10\t\x12\x1b\n\x17RESPONSE_STATUS_UNKNOWN\x10\nB$\n\x11\x63om.apexnova.stubB\rResponseProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apexnova.stub.response_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.apexnova.stubB\rResponseProtoP\001'
  _globals['_RESPONSESTATUS']._serialized_start=114
  _globals['_RESPONSESTATUS']._serialized_end=509
  _globals['_STANDARDRESPONSE']._serialized_start=32
  _globals['_STANDARDRESPONSE']._serialized_end=111
# @@protoc_insertion_point(module_scope)
