# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apexnova/notification/notification_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'apexnova/notification/notification_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from apexnova.notification import notification_pb2 as apexnova_dot_notification_dot_notification__pb2
from apexnova.stub import authorization_context_pb2 as apexnova_dot_stub_dot_authorization__context__pb2
from apexnova.stub import response_pb2 as apexnova_dot_stub_dot_response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0apexnova/notification/notification_service.proto\x12\x0cnotification\x1a(apexnova/notification/notification.proto\x1a)apexnova/stub/authorization_context.proto\x1a\x1c\x61pexnova/stub/response.proto\"\x85\x01\n\x10SendEmailRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12;\n\x12\x65mail_notification\x18\x02 \x01(\x0b\x32\x1f.notification.EmailNotification\"\x7f\n\x0eSendSMSRequest\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\x37\n\x10sms_notification\x18\x02 \x01(\x0b\x32\x1d.notification.SMSNotification\"H\n\x18SendNotificationResponse\x12,\n\x11standard_response\x18\x01 \x01(\x0b\x32\x11.StandardResponse2\xbb\x01\n\x13NotificationService\x12S\n\tSendEmail\x12\x1e.notification.SendEmailRequest\x1a&.notification.SendNotificationResponse\x12O\n\x07SendSMS\x12\x1c.notification.SendSMSRequest\x1a&.notification.SendNotificationResponseB7\n\x19\x63om.apexnova.notificationB\x18NotificationServiceProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apexnova.notification.notification_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.apexnova.notificationB\030NotificationServiceProtoP\001'
  _globals['_SENDEMAILREQUEST']._serialized_start=182
  _globals['_SENDEMAILREQUEST']._serialized_end=315
  _globals['_SENDSMSREQUEST']._serialized_start=317
  _globals['_SENDSMSREQUEST']._serialized_end=444
  _globals['_SENDNOTIFICATIONRESPONSE']._serialized_start=446
  _globals['_SENDNOTIFICATIONRESPONSE']._serialized_end=518
  _globals['_NOTIFICATIONSERVICE']._serialized_start=521
  _globals['_NOTIFICATIONSERVICE']._serialized_end=708
# @@protoc_insertion_point(module_scope)
