# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apexnova/identity/user/user_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'apexnova/identity/user/user_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from apexnova.identity.user import user_pb2 as apexnova_dot_identity_dot_user_dot_user__pb2
from apexnova.stub import response_pb2 as apexnova_dot_stub_dot_response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)apexnova/identity/user/user_service.proto\x12\x08identity\x1a!apexnova/identity/user/user.proto\x1a\x1c\x61pexnova/stub/response.proto\"\x1d\n\x0fReadUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\"^\n\x10ReadUserResponse\x12\x1c\n\x04user\x18\x01 \x01(\x0b\x32\x0e.identity.User\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"0\n\x11\x43reateUserRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"`\n\x12\x43reateUserResponse\x12\x1c\n\x04user\x18\x01 \x01(\x0b\x32\x0e.identity.User\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"1\n\x11UpdateUserRequest\x12\x1c\n\x04user\x18\x01 \x01(\x0b\x32\x0e.identity.User\"`\n\x12UpdateUserResponse\x12\x1c\n\x04user\x18\x01 \x01(\x0b\x32\x0e.identity.User\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"\x1f\n\x11\x44\x65leteUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\"N\n\x12\x44\x65leteUserResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12,\n\x11standard_response\x18\x02 \x01(\x0b\x32\x11.StandardResponse\"%\n\x16ReadUsersStreamRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t2\xf2\x02\n\x0bUserService\x12G\n\nCreateUser\x12\x1b.identity.CreateUserRequest\x1a\x1c.identity.CreateUserResponse\x12\x41\n\x08ReadUser\x12\x19.identity.ReadUserRequest\x1a\x1a.identity.ReadUserResponse\x12G\n\nUpdateUser\x12\x1b.identity.UpdateUserRequest\x1a\x1c.identity.UpdateUserResponse\x12G\n\nDeleteUser\x12\x1b.identity.DeleteUserRequest\x1a\x1c.identity.DeleteUserResponse\x12\x45\n\x0fReadUsersStream\x12 .identity.ReadUsersStreamRequest\x1a\x0e.identity.User0\x01\x42+\n\x15\x63om.apexnova.identityB\x10UserServiceProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apexnova.identity.user.user_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.apexnova.identityB\020UserServiceProtoP\001'
  _globals['_READUSERREQUEST']._serialized_start=120
  _globals['_READUSERREQUEST']._serialized_end=149
  _globals['_READUSERRESPONSE']._serialized_start=151
  _globals['_READUSERRESPONSE']._serialized_end=245
  _globals['_CREATEUSERREQUEST']._serialized_start=247
  _globals['_CREATEUSERREQUEST']._serialized_end=295
  _globals['_CREATEUSERRESPONSE']._serialized_start=297
  _globals['_CREATEUSERRESPONSE']._serialized_end=393
  _globals['_UPDATEUSERREQUEST']._serialized_start=395
  _globals['_UPDATEUSERREQUEST']._serialized_end=444
  _globals['_UPDATEUSERRESPONSE']._serialized_start=446
  _globals['_UPDATEUSERRESPONSE']._serialized_end=542
  _globals['_DELETEUSERREQUEST']._serialized_start=544
  _globals['_DELETEUSERREQUEST']._serialized_end=575
  _globals['_DELETEUSERRESPONSE']._serialized_start=577
  _globals['_DELETEUSERRESPONSE']._serialized_end=655
  _globals['_READUSERSSTREAMREQUEST']._serialized_start=657
  _globals['_READUSERSSTREAMREQUEST']._serialized_end=694
  _globals['_USERSERVICE']._serialized_start=697
  _globals['_USERSERVICE']._serialized_end=1067
# @@protoc_insertion_point(module_scope)
