# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apexnova/notification/notification.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'apexnova/notification/notification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from apexnova.stub import authorization_context_pb2 as apexnova_dot_stub_dot_authorization__context__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(apexnova/notification/notification.proto\x12\x0cnotification\x1a)apexnova/stub/authorization_context.proto\"\xfa\x02\n\x11\x45mailNotification\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\x12\n\nrecipients\x18\x02 \x03(\t\x12\x15\n\rcc_recipients\x18\x03 \x03(\t\x12\x16\n\x0e\x62\x63\x63_recipients\x18\x04 \x03(\t\x12\x0f\n\x07subject\x18\x05 \x01(\t\x12H\n\rtemplate_data\x18\x06 \x03(\x0b\x32\x31.notification.EmailNotification.TemplateDataEntry\x12\x13\n\x0b\x61ttachments\x18\x07 \x03(\t\x12\x11\n\treply_tos\x18\x08 \x03(\t\x12\x34\n\x08\x63\x61tegory\x18\t \x01(\x0e\x32\".notification.NotificationCategory\x1a\x33\n\x11TemplateDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa1\x01\n\x0fSMSNotification\x12\x34\n\x15\x61uthorization_context\x18\x01 \x01(\x0b\x32\x15.AuthorizationContext\x12\x11\n\trecipient\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x34\n\x08\x63\x61tegory\x18\x04 \x01(\x0e\x32\".notification.NotificationCategory*\xb2\x01\n\x14NotificationCategory\x12%\n!NOTIFICATION_CATEGORY_UNSPECIFIED\x10\x00\x12#\n\x1fNOTIFICATION_CATEGORY_MARKETING\x10\x01\x12\'\n#NOTIFICATION_CATEGORY_TRANSACTIONAL\x10\x02\x12%\n!NOTIFICATION_CATEGORY_PROMOTIONAL\x10\x03\x42\x30\n\x19\x63om.apexnova.notificationB\x11NotificationProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apexnova.notification.notification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.apexnova.notificationB\021NotificationProtoP\001'
  _globals['_EMAILNOTIFICATION_TEMPLATEDATAENTRY']._loaded_options = None
  _globals['_EMAILNOTIFICATION_TEMPLATEDATAENTRY']._serialized_options = b'8\001'
  _globals['_NOTIFICATIONCATEGORY']._serialized_start=647
  _globals['_NOTIFICATIONCATEGORY']._serialized_end=825
  _globals['_EMAILNOTIFICATION']._serialized_start=102
  _globals['_EMAILNOTIFICATION']._serialized_end=480
  _globals['_EMAILNOTIFICATION_TEMPLATEDATAENTRY']._serialized_start=429
  _globals['_EMAILNOTIFICATION_TEMPLATEDATAENTRY']._serialized_end=480
  _globals['_SMSNOTIFICATION']._serialized_start=483
  _globals['_SMSNOTIFICATION']._serialized_end=644
# @@protoc_insertion_point(module_scope)
